@@ -1,6 +1,6 @@
 <?php
 /*
- * $Horde: passwd/menu.php,v 1.1.1.1 2002/05/22 02:58:57 ericr Exp $
+ * $Horde: passwd/menu.php,v 1.1.1.1.2.1 2002/10/07 01:13:22 ericr Exp $
  *
  * Copyright 1999-2002 Charles J. Hagenbuch <chuck@horde.org>
  * Copyright 1999-2002 Jon Parise <jon@horde.org>
@@ -26,7 +26,7 @@ if (@is_readable(PASSWD_BASE . '/config/menu.php')) {
     }
 }
 
-require $registry->getTemplatePath() . '/menu.inc';
+require $registry->getTemplatePath() . '/menu/menu.inc';
 
 /* Include the JavaScript for the help system (if enabled). */
 if ($conf['user']['online_help'] && $browser->hasFeature('javascript')) {
